{% load i18n admin_urls static %}
<div class="js-inline-admin-formset inline-group" id="{{ inline_admin_formset.formset.prefix }}-group" data-inline-type="stacked" data-inline-formset="{{ inline_admin_formset.inline_formset_data }}">
    <fieldset class="module {{ inline_admin_formset.classes }} card card-outline">
        <div class="card-header with-border">
            <h2 class="card-title">{{ inline_admin_formset.opts.verbose_name_plural|capfirst }}</h2>
        </div>
        <div class="card-body">
                {{ inline_admin_formset.formset.management_form }}
                {{ inline_admin_formset.formset.non_form_errors }}

                {% for inline_admin_form in inline_admin_formset %}
                    <div class="panel card inline-related{% if inline_admin_form.original or inline_admin_form.show_url %} has_original{% endif %}{% if forloop.last and inline_admin_formset.has_add_permission %} empty-form last-related{% endif %}" id="{{ inline_admin_formset.formset.prefix }}-{% if not forloop.last %}{{ forloop.counter0 }}{% else %}empty{% endif %}">
                        <div class="card-header with-border">
                            <h3 class="card-title">
                                <b>{{ inline_admin_formset.opts.verbose_name|capfirst }}:</b>&nbsp;
                                <span class="inline_label">
                                    {% if inline_admin_form.original %}
                                        {{ inline_admin_form.original }}
                                        {% if inline_admin_form.model_admin.show_change_link and inline_admin_form.model_admin.has_registered_model %}
                                            <a href="{% url inline_admin_form.model_admin.opts|admin_urlname:'change' inline_admin_form.original.pk|admin_urlquote %}" class="{% if inline_admin_formset.has_change_permission %}inlinechangelink{% else %}inlineviewlink{% endif %}">
                                            {% if inline_admin_formset.has_change_permission %}
                                                {% trans "Change" %}
                                            {% else %}
                                                {% trans "View" %}
                                            {% endif %}
                                            </a>
                                        {% endif %}
                                    {% else %}
                                        #{{ forloop.counter }}
                                    {% endif %}
                                </span>
                                {% if inline_admin_form.show_url %}
                                    <a href="{{ inline_admin_form.absolute_url }}">{% trans "View on site" %}</a>
                                {% endif %}
                            </h3>
                            {% if inline_admin_formset.formset.can_delete and inline_admin_form.original %}
                                <span class="card-tools float-right delete">
                                  {{ inline_admin_form.deletion_field.field }} {{ inline_admin_form.deletion_field.label_tag }}
                                </span>
                            {% endif %}

                        </div>
                        <div class="card-body">
                            {% if inline_admin_form.form.non_field_errors %}{{ inline_admin_form.form.non_field_errors }}{% endif %}
                            {% for fieldset in inline_admin_form %}
                                {% include "admin/includes/fieldset.html" %}
                            {% endfor %}
                            {% if inline_admin_form.needs_explicit_pk_field %}{{ inline_admin_form.pk_field.field }}{% endif %}
                            {% if inline_admin_form.fk_field %}{{ inline_admin_form.fk_field.field }}{% endif %}
                        </div>
                    </div>
                {% endfor %}
        </div>
    </fieldset>
</div>
