{% load i18n admin_urls %}
{% block object-tools-items %}
    {% if perms.administration.can_change_logs or perms.administration.can_view_logs %}
        {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
        <a class="btn btn-block btn-outline-secondary btn-sm" href="{% add_preserved_filters history_url %}">{% trans 'History' %}</a>
    {% endif %}
    {% if has_absolute_url %}
        <a href="{{ absolute_url }}" class="btn btn-block btn-outline-secondary btn-sm">{% trans "View on site" %}</a>
    {% endif %}
{% endblock %}
