{% load admin_list jazzmin %}
{% load i18n %}

<div class="col-5">
    <div class="dataTables_info" role="status" aria-live="polite">
        {{ cl.result_count }}
        {% if cl.result_count == 1 %}
            {{ cl.opts.verbose_name }}
        {% else %}
            {{ cl.opts.verbose_name_plural }}
        {% endif %}

        {% if show_all_url %}&nbsp;&nbsp;
            <a href="{{ show_all_url }}" class="btn btn-outline-primary">{% trans 'Show all' %}</a>
        {% endif %}
        {% if cl.formset and cl.result_count %}
            <input type="submit" name="_save" class="btn btn-primary" value="{% trans 'Save' %}">
        {% endif %}
    </div>
</div>

<div class="col-7">
    <ul class="pagination pagination-sm m-0 float-right">
        {% if pagination_required %}
            <li class="page-item previous disabled">
                <a class="page-link" href="#" data-dt-idx="0" tabindex="0">«</a>
            </li>
            {% for i in page_range %}
                {% jazzmin_paginator_number cl i %}
            {% endfor %}
            <li class="page-item next disabled">
                <a class="page-link" href="#" data-dt-idx="7" tabindex="0">»</a>
            </li>
        {% endif %}
    </ul>
</div>
