{% extends "admin/base_site.html" %}
{% load i18n admin_urls static %}

{% block breadcrumbs %}
<ol class="breadcrumb float-sm-right">
    <li class="breadcrumb-item"><a href="{% url 'admin:index' %}"><i class="fa fa-tachometer-alt"></i> {% trans 'Home' %}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a></li>
    <li class="breadcrumb-item"><a href="{% url opts|admin_urlname:'changelist' %}">{{ module_name }}</a></li>
    <li class="breadcrumb-item"><a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">{{ object|truncatewords:"18" }}</a></li>
    <li class="breadcrumb-item active">{% trans 'History' %}</li>
</ol>
{% endblock %}

{% block content %}

<div class="row col-md-12">
    <div class=col-12>
        <div class="card card-primary card-outline">
            <div class="card-header with-border">
                <h4 class="card-title">
                    {% trans 'History' %}
                </h4>
            </div>

            <div class="card-body">
                <div id="content-main">
                    <div class="module">
                        {% if action_list %}
                        <table id="change-history" class="table table-bordered table-hover dataTable">
                            <thead>
                            <tr>
                                <th scope="col">{% trans 'Date/time' %}</th>
                                <th scope="col">{% trans 'User' %}</th>
                                <th scope="col">{% trans 'Action' %}</th>
                            </tr>
                            </thead>
                            <tbody>
                            {% for action in action_list %}
                            <tr>
                                <th scope="row">{{ action.action_time|date:"DATETIME_FORMAT" }}</th>
                                <td>{{ action.user.get_username }}{% if action.user.get_full_name %} ({{ action.user.get_full_name }}){% endif %}</td>
                                <td>{{ action.get_change_message }}</td>
                            </tr>
                            {% endfor %}
                            </tbody>
                        </table>
                        {% else %}
                        <p>{% trans "This object doesn't have a change history. It probably wasn't added via this admin site." %}</p>
                        {% endif %}
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

{% endblock %}
