{% load i18n static jazzmin %}
{% get_jazzmin_settings as jazzmin_settings %}

<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<html lang="{{ LANGUAGE_CODE|default:" en-us" }}" {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>
<head>
    <!-- Current language: {{ LANGUAGE_CODE }} -->
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>{{ jazzmin_settings.site_title }} | {% trans 'Log in again' %}</title>
    <!-- Tell the browser to be responsive to screen width -->
    <meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
    <!-- Bootstrap 4.5.0 -->
    <link rel="stylesheet" href="//stackpath.bootstrapcdn.com/bootstrap/4.5.0/css/bootstrap.min.css">
    <!-- Font Awesome -->
    <link rel="stylesheet" href=//use.fontawesome.com/releases/v5.13.0/css/all.css">
    <link rel="stylesheet" href="//use.fontawesome.com/releases/v5.13.0/css/v4-shims.css">
    <!-- Theme style -->
    <link rel="stylesheet" href={% static "adminlte/css/adminlte.min.css" %}>

    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
    <script src="//oss.maxcdn.com/html5shiv/3.7.3/html5shiv.min.js"></script>
    <script src="//oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
</head>
<body class="hold-transition login-page">

<div class="login-box">
    <div class="login-logo">
        <a href="/">
            <b>{{ jazzmin_settings.site_header }}</b>
        </a>
    </div>

    <div class="login-box-body">
        <p class="login-box-msg">{{ jazzmin_settings.welcome_sign }}</p>
        <p class="text-center">{% trans "Thanks for spending some quality time with the Web site today." %}</p>
        <p class="text-center"><a class="btn btn-primary" href="{% url 'admin:index' %}">{% trans 'Log in again' %}</a>
        </p>
    </div>
</div>

</body>
</html>
